@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2007,      Jason Kivlighn (jkivlighn@gmail.com)
  * Copyright (C) 2008-2009, Nokia
@@ -22,15 +21,15 @@
 #include "config.h"
 
 #include <string.h>
+
 #include <glib.h>
 
 #include <libxml/HTMLparser.h>
-#include <libtracker-common/tracker-statement-list.h>
-
-#include "tracker-main.h"
 
 #include <libtracker-common/tracker-ontology.h>
 
+#include <libtracker-extract/tracker-extract.h>
+
 #define RDF_TYPE TRACKER_RDF_PREFIX "type"
 
 typedef enum {
@@ -256,7 +255,7 @@ extract_html (const gchar          *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
