@@ -43,14 +43,15 @@
 
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-ontology.h>
-#include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-utils.h>
 
+#include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-xmp.h>
+#include <libtracker-extract/tracker-iptc.h>
+#include <libtracker-extract/tracker-exif.h>
+
 #include "tracker-main.h"
-#include "tracker-xmp.h"
-#include "tracker-iptc.h"
-#include "tracker-exif.h"
 
 #ifdef HAVE_LIBEXIF
 #define EXIF_NAMESPACE          "Exif"
@@ -216,7 +217,7 @@ extract_jpeg (const gchar          *uri,
 			gsize len;
 #ifdef HAVE_LIBIPTCDATA
 			gsize offset;
-			gsize sublen;
+			guint sublen;
 #endif /* HAVE_LIBIPTCDATA */
 
 			switch (marker->marker) {
@@ -231,7 +232,7 @@ extract_jpeg (const gchar          *uri,
 
 #ifdef HAVE_LIBEXIF
 				if (strncmp (EXIF_NAMESPACE, str, EXIF_NAMESPACE_LENGTH) == 0) {
-					tracker_read_exif ((unsigned char*) marker->data,
+					tracker_exif_read ((unsigned char*) marker->data,
 					                   len,
 					                   uri,
 					                   &ed);
@@ -240,7 +241,7 @@ extract_jpeg (const gchar          *uri,
 
 #ifdef HAVE_EXEMPI
 				if (strncmp (XMP_NAMESPACE, str, XMP_NAMESPACE_LENGTH) == 0) {
-					tracker_read_xmp (str + XMP_NAMESPACE_LENGTH,
+					tracker_xmp_read (str + XMP_NAMESPACE_LENGTH,
 					                  len - XMP_NAMESPACE_LENGTH,
 					                  uri,
 					                  &xd);
@@ -256,7 +257,7 @@ extract_jpeg (const gchar          *uri,
 				if (strncmp (PS3_NAMESPACE, str, PS3_NAMESPACE_LENGTH) == 0) {
 					offset = iptc_jpeg_ps3_find_iptc (str, len, &sublen);
 					if (offset > 0) {
-						tracker_read_iptc (str + offset,
+						tracker_iptc_read (str + offset,
 						                   sublen,
 						                   uri,
 						                   &id);
@@ -275,13 +276,13 @@ extract_jpeg (const gchar          *uri,
 		}
 
 		/* Don't merge if the make is in the model */
-		if ((xd.Make == NULL || xd.Model == NULL) ||
-		    (xd.Make && xd.Model && strstr (xd.Model, xd.Make) == NULL)) {
-			md.camera = tracker_merge (" ", 2, xd.Make, xd.Model);
+		if ((xd.make == NULL || xd.model == NULL) ||
+		    (xd.make && xd.model && strstr (xd.model, xd.make) == NULL)) {
+			md.camera = tracker_merge (" ", 2, xd.make, xd.model);
 		} else {
-			md.camera = g_strdup (xd.Model);
-			g_free (xd.Model);
-			g_free (xd.Make);
+			md.camera = g_strdup (xd.model);
+			g_free (xd.model);
+			g_free (xd.make);
 		}
 
 		if (!md.camera) {
@@ -298,24 +299,24 @@ extract_jpeg (const gchar          *uri,
 			g_free (ed.make);
 		}
 
-		md.title = tracker_coalesce (3, xd.title, xd.Title, ed.document_name, xd.PDFtitle);
-		md.orientation = tracker_coalesce (3, ed.orientation, xd.Orientation, id.image_orientation);
-		md.copyright = tracker_coalesce (3, ed.copyright, xd.Copyright, xd.rights, id.copyright_notice);
-		md.white_balance = tracker_coalesce (2, ed.white_balance, xd.WhiteBalance);
-		md.fnumber =  tracker_coalesce (2, ed.fnumber, xd.FNumber);
-		md.flash =  tracker_coalesce (2, ed.flash, xd.Flash);
-		md.focal_length =  tracker_coalesce (2, ed.focal_length, xd.FocalLength);
-		md.artist =  tracker_coalesce (3, ed.artist, xd.Artist, xd.contributor);
-		md.exposure_time =  tracker_coalesce (2, ed.exposure_time, xd.ExposureTime);
-		md.iso_speed_ratings =  tracker_coalesce (2, ed.iso_speed_ratings, xd.ISOSpeedRatings);
-		md.date =  tracker_coalesce (5, ed.time, xd.date, id.date_created, ed.time_original, xd.DateTimeOriginal);
+		md.title = tracker_coalesce (3, xd.title, xd.title2, ed.document_name, xd.pdf_title);
+		md.orientation = tracker_coalesce (3, ed.orientation, xd.orientation, id.image_orientation);
+		md.copyright = tracker_coalesce (3, ed.copyright, xd.copyright, xd.rights, id.copyright_notice);
+		md.white_balance = tracker_coalesce (2, ed.white_balance, xd.white_balance);
+		md.fnumber =  tracker_coalesce (2, ed.fnumber, xd.fnumber);
+		md.flash =  tracker_coalesce (2, ed.flash, xd.flash);
+		md.focal_length =  tracker_coalesce (2, ed.focal_length, xd.focal_length);
+		md.artist =  tracker_coalesce (3, ed.artist, xd.artist, xd.contributor);
+		md.exposure_time =  tracker_coalesce (2, ed.exposure_time, xd.exposure_time);
+		md.iso_speed_ratings =  tracker_coalesce (2, ed.iso_speed_ratings, xd.iso_speed_ratings);
+		md.date =  tracker_coalesce (5, ed.time, xd.date, id.date_created, ed.time_original, xd.time_original);
 		md.description = tracker_coalesce (2, ed.description, xd.description);
-		md.metering_mode = tracker_coalesce (2, ed.metering_mode, xd.MeteringMode);
+		md.metering_mode = tracker_coalesce (2, ed.metering_mode, xd.metering_mode);
 
-		md.city = tracker_coalesce (2, id.city, xd.City);
-		md.state = tracker_coalesce (2, id.state, xd.State);
-		md.address = tracker_coalesce (2, id.sublocation, xd.Address);
-		md.country  = tracker_coalesce (2, id.countryname, xd.Country);
+		md.city = tracker_coalesce (2, id.city, xd.city);
+		md.state = tracker_coalesce (2, id.state, xd.state);
+		md.address = tracker_coalesce (2, id.sublocation, xd.address);
+		md.country  = tracker_coalesce (2, id.country_name, xd.country);
 
 		md.creator =  tracker_coalesce (3, id.byline, xd.creator, id.credit);
 		md.comment = tracker_coalesce (2, comment, ed.user_comment);
@@ -340,15 +341,15 @@ extract_jpeg (const gchar          *uri,
 			g_free (id.contact);
 		}
 
-		if (id.bylinetitle) {
+		if (id.byline_title) {
 			tracker_sparql_builder_predicate (metadata, "nco:hasAffiliation");
 			tracker_sparql_builder_object_blank_open (metadata);
 			tracker_sparql_builder_predicate (metadata, "a");
 			tracker_sparql_builder_object (metadata, "nco:Affiliation");
 			tracker_sparql_builder_predicate (metadata, "nco:title");
-			tracker_sparql_builder_object_unvalidated (metadata, id.bylinetitle);
+			tracker_sparql_builder_object_unvalidated (metadata, id.byline_title);
 			tracker_sparql_builder_object_blank_close (metadata);
-			g_free (id.bylinetitle);
+			g_free (id.byline_title);
 		}
 
 		if (xd.keywords) {
@@ -356,9 +357,9 @@ extract_jpeg (const gchar          *uri,
 			g_free (xd.keywords);
 		}
 
-		if (xd.PDFkeywords) {
-			insert_keywords (metadata, xd.PDFkeywords);
-			g_free (xd.PDFkeywords);
+		if (xd.pdf_keywords) {
+			insert_keywords (metadata, xd.pdf_keywords);
+			g_free (xd.pdf_keywords);
 		}
 
 		if (xd.subject) {
@@ -591,7 +592,7 @@ extract_jpeg (const gchar          *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
