@@ -23,9 +23,7 @@
 
 #include <glib.h>
 
-#include <libtracker-common/tracker-statement-list.h>
-
-#include "tracker-main.h"
+#include <libtracker-extract/tracker-extract.h>
 
 #undef  TRY_LOCALE_TO_UTF8_CONVERSION
 
@@ -296,7 +294,7 @@ extract_text (const gchar          *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
