@@ -26,9 +26,10 @@
 #include <gio/gio.h>
 
 #include <libtracker-common/tracker-dbus.h>
-#include <libtracker-common/tracker-sparql-builder.h>
 #include <libtracker-common/tracker-log.h>
 
+#include <libtracker-extract/tracker-extract.h>
+
 #include "tracker-dbus.h"
 #include "tracker-extract.h"
 #include "tracker-main.h"
@@ -56,15 +57,9 @@ typedef struct {
 	const TrackerExtractData *edata;
 }  ModuleData;
 
-enum {
-	QUEUE_THUMBNAIL,
-	LAST_SIGNAL
-};
 
 static void tracker_extract_finalize (GObject *object);
 
-static guint signals[LAST_SIGNAL] = {0};
-
 G_DEFINE_TYPE(TrackerExtract, tracker_extract, G_TYPE_OBJECT)
 
 static void
@@ -76,18 +71,6 @@ tracker_extract_class_init (TrackerExtractClass *klass)
 
 	object_class->finalize = tracker_extract_finalize;
 
-	signals[QUEUE_THUMBNAIL] =
-		g_signal_new ("queue-thumbnail",
-		              G_TYPE_FROM_CLASS (klass),
-		              G_SIGNAL_RUN_LAST,
-		              0,
-		              NULL, NULL,
-		              tracker_marshal_VOID__STRING_STRING,
-		              G_TYPE_NONE,
-		              2,
-		              G_TYPE_STRING,
-		              G_TYPE_STRING);
-
 	g_type_class_add_private (object_class, sizeof (TrackerExtractPrivate));
 }
 
@@ -183,7 +166,7 @@ tracker_extract_new (gboolean disable_shutdown,
 
 		g_module_make_resident (module);
 
-		if (g_module_symbol (module, "tracker_get_extract_data", (gpointer *) &func)) {
+		if (g_module_symbol (module, "tracker_extract_get_data", (gpointer *) &func)) {
 			ModuleData mdata;
 
 			mdata.module = module;
@@ -337,7 +320,7 @@ get_file_metadata (TrackerExtract        *extract,
 				                              "  Extracting with module:'%s'",
 				                              g_module_name ((GModule*) mdata.module));
 
-				(*edata->extract) (uri, statements);
+				(*edata->func) (uri, statements);
 
 				items = tracker_sparql_builder_get_length (statements);
 
@@ -372,7 +355,7 @@ get_file_metadata (TrackerExtract        *extract,
 				                              "  Extracting with module:'%s'",
 				                              g_module_name ((GModule*) mdata.module));
 
-				(*edata->extract) (uri, statements);
+				(*edata->func) (uri, statements);
 
 				items = tracker_sparql_builder_get_length (statements);
 
