@@ -1,8 +1,7 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia
-
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
  * License as published by the Free Software Foundation; either
@@ -318,6 +317,22 @@ get_writeback_predicates (void)
 	return predicates_to_signal;
 }
 
+static void
+config_verbosity_changed_cb (GObject    *object,
+                             GParamSpec *spec,
+                             gpointer    user_data)
+{
+	gint verbosity;
+
+	verbosity = tracker_config_get_verbosity (TRACKER_CONFIG (object));
+
+	g_message ("Log verbosity is set to %d, %s D-Bus client lookup",
+	           verbosity,
+	           verbosity > 0 ? "enabling" : "disabling");
+
+	tracker_dbus_enable_client_lookup (verbosity > 0);
+}
+
 gint
 main (gint argc, gchar *argv[])
 {
@@ -327,7 +342,6 @@ main (gint argc, gchar *argv[])
 	TrackerConfig *config;
 	TrackerDBManagerFlags flags = 0;
 	gboolean is_first_time_index;
-	gboolean need_journal;
 
 	g_type_init ();
 
@@ -394,9 +408,16 @@ main (gint argc, gchar *argv[])
 	/* Initialize major subsystems */
 	config = tracker_config_new ();
 
+	g_signal_connect (config, "notify::verbosity",
+	                  G_CALLBACK (config_verbosity_changed_cb),
+	                  NULL);
+
 	/* Daemon command line arguments */
 	if (verbosity > -1) {
 		tracker_config_set_verbosity (config, verbosity);
+	} else {
+		/* Make sure we enable/disable the dbus client lookup */
+		config_verbosity_changed_cb (G_OBJECT (config), NULL, NULL);
 	}
 
 	if (low_memory) {
@@ -431,12 +452,11 @@ main (gint argc, gchar *argv[])
 
 	if (!tracker_data_manager_init (flags,
 	                                NULL,
-	                                &is_first_time_index,
-	                                &need_journal)) {
+	                                &is_first_time_index)) {
 		return EXIT_FAILURE;
 	}
 
-	tracker_store_init (need_journal);
+	tracker_store_init ();
 
 	if (private->shutdown) {
 		goto shutdown;
@@ -486,6 +506,7 @@ main (gint argc, gchar *argv[])
 	tracker_data_manager_shutdown ();
 	tracker_log_shutdown ();
 
+	g_signal_handlers_disconnect_by_func (config, config_verbosity_changed_cb, NULL);
 	g_object_unref (config);
 
 	g_print ("\nOK\n\n");
