@@ -518,14 +518,12 @@ get_music_albums (TrackerClient *client,
 	fts = get_fts_string (search_words, use_or_operator);
 
 	if (fts) {
-		query = g_strdup_printf ("SELECT ?album ?title COUNT(?song) "
+		query = g_strdup_printf ("SELECT ?album nie:title (?title) COUNT(?song) "
 		                         "AS songs "
-		                         "SUM(?length) AS totallength "
+		                         "SUM(nmm:length (?length)) AS totallength "
 		                         "WHERE {"
-		                         "  ?album a nmm:MusicAlbum ;"
-		                         "  nie:title ?title ."
-		                         "  ?song nmm:musicAlbum ?album ;"
-		                         "  nmm:length ?length ."
+		                         "  ?album a nmm:MusicAlbum ."
+		                         "  ?song nmm:musicAlbum ?album ."
 		                         "  ?album fts:match \"%s\" "
 		                         "} "
 		                         "GROUP BY ?album "
@@ -535,14 +533,12 @@ get_music_albums (TrackerClient *client,
 		                         search_offset,
 		                         search_limit);
 	} else {
-		query = g_strdup_printf ("SELECT ?album ?title COUNT(?song) "
+		query = g_strdup_printf ("SELECT ?album nie:title (?title) COUNT(?song) "
 		                         "AS songs "
-		                         "SUM(?length) AS totallength "
+		                         "SUM(nmm:length (?length)) AS totallength "
 		                         "WHERE {"
-		                         "  ?album a nmm:MusicAlbum ;"
-		                         "  nie:title ?title ."
-		                         "  ?song nmm:musicAlbum ?album ;"
-		                         "  nmm:length ?length ."
+		                         "  ?album a nmm:MusicAlbum ."
+		                         "  ?song nmm:musicAlbum ?album ." 
 		                         "} "
 		                         "GROUP BY ?album "
 		                         "OFFSET %d "
@@ -833,6 +829,51 @@ main (int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
+	g_type_init ();
+
+	if (!g_thread_supported ()) {
+		g_thread_init (NULL);
+	}
+
+	/* Check terms are not stopwords */
+	if (terms) {
+		TrackerLanguage *language;
+		GHashTable *stop_words;
+		const gchar *stop_word_found;
+		gchar **p;
+
+		language = tracker_language_new (NULL);
+		stop_words = tracker_language_get_stop_words (language);
+
+		for (p = terms, stop_word_found = NULL; *p && !stop_word_found; p++) {
+			gpointer data;
+
+			data = g_hash_table_lookup (stop_words, *p);
+			if (data) {
+				stop_word_found = *p;
+			}
+		}
+
+		if (stop_word_found) {
+			g_printerr (_("Search term '%s' is a stop word."),
+			            stop_word_found);
+			g_printerr ("\n\n");
+			g_printerr (_("Stop words are common words which are "
+			              "ignored during the indexing process."));
+			g_printerr ("\n");
+			g_printerr (_("This means this search term will never "
+			              "be found when matching FTS entries."));
+			g_printerr ("\n\n");
+
+			g_option_context_free (context);
+			g_object_unref (language);
+
+			return EXIT_FAILURE;
+		}
+
+		g_object_unref (language);
+	}
+
 	g_option_context_free (context);
 
 	client = tracker_client_new (0, G_MAXINT);
